<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AlertDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>BackupWidget</name>
    <message>
        <source>Backing up…</source>
        <translation>备份中...</translation>
    </message>
    <message>
        <source>Backing up the current system, please wait patiently</source>
        <translation>系统升级前需要为您备份，请耐心等待</translation>
    </message>
</context>
<context>
    <name>BorderRadiusHeaderView</name>
    <message>
        <source>All</source>
        <translation>全选</translation>
    </message>
</context>
<context>
    <name>CheckImageResultWidget</name>
    <message>
        <source>File size:</source>
        <translation>镜像大小</translation>
    </message>
    <message>
        <source>ISO version:</source>
        <translation>镜像版本</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>检查中</translation>
    </message>
    <message>
        <source>The image file is ready</source>
        <translation>镜像已准备好</translation>
    </message>
    <message>
        <source>Some applications may not work properly after the upgrade.</source>
        <translation>升级后,部分应用可能出现无法正常使用等异常情况！</translation>
    </message>
    <message>
        <source>The upgrade may take a long time. Please plug in to avoid interruption.</source>
        <translation type="vanished">升级时间可能较长，请插上电源以免升级中断</translation>
    </message>
    <message>
        <source>The version or integrity of the image file does not meet requirements.</source>
        <translation>镜像版本或完整性不符</translation>
    </message>
</context>
<context>
    <name>CheckImageWidget</name>
    <message>
        <source>Verifying the integrity…</source>
        <translation>正在检查镜像完整性...</translation>
    </message>
</context>
<context>
    <name>CheckResultType</name>
    <message>
        <source>%1 (%2)</source>
        <translation type="obsolete">%1 (%2)</translation>
    </message>
    <message>
        <source>Too old</source>
        <translation type="obsolete">版本过低</translation>
    </message>
    <message>
        <source>Activated</source>
        <translation type="obsolete">已激活</translation>
    </message>
    <message>
        <source>Unactivated</source>
        <translation type="obsolete">未激活</translation>
    </message>
    <message>
        <source>Requirement: %1 GB</source>
        <translation type="obsolete">基线要求：%1 GB</translation>
    </message>
    <message>
        <source>Data disk %1 GB / %2 GB</source>
        <translation type="obsolete">数据盘 %1 GB/%2 GB</translation>
    </message>
    <message>
        <source>System disk %1 GB / %2 GB</source>
        <translation type="obsolete">系统盘 %1 GB/%2 GB</translation>
    </message>
</context>
<context>
    <name>CheckSizeThread</name>
    <message>
        <source>Unable to get the image file.</source>
        <translation>获取镜像失败</translation>
    </message>
</context>
<context>
    <name>ConditionChecklistWidget</name>
    <message>
        <source>System version</source>
        <translation>系统版本</translation>
    </message>
    <message>
        <source>The system version is too old, and the upgrade may fail. To upgrade successfully, please update your system to the latest version in the Control Center first (you can ignore it and force an upgrade as well).</source>
        <translation>当前系统版本过低，存在升级失败的风险！为保证升级成功率，请先通过控制中心-系统更新升级至最新操作系统（也可保持现状强行升级）。</translation>
    </message>
    <message>
        <source>Requirement: deepin (%1)</source>
        <translation>基线要求：deepin (%1)</translation>
    </message>
    <message>
        <source>Requirement: Professional (%1)</source>
        <translation>基线要求：专业版 (%1)</translation>
    </message>
    <message>
        <source>Authorization status</source>
        <translation>系统激活状态</translation>
    </message>
    <message>
        <source>Requirement: Activated</source>
        <translation>基线要求：激活</translation>
    </message>
    <message>
        <source>CPU architecture</source>
        <translation>CPU架构</translation>
    </message>
    <message>
        <source>Requirement: X86</source>
        <translation>基线要求：X86</translation>
    </message>
    <message>
        <source>Storage space</source>
        <translation>存储空间</translation>
    </message>
    <message>
        <source>There are risks, but you can force an upgrade.</source>
        <translation>存在升级风险，但您可以强制升级</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation type="vanished">%1 (%2)</translation>
    </message>
    <message>
        <source>Too old</source>
        <translation>版本过低</translation>
    </message>
    <message>
        <source>Activated</source>
        <translation>已激活</translation>
    </message>
    <message>
        <source>Unactivated</source>
        <translation>未激活</translation>
    </message>
    <message>
        <source>Requirement: %1 GB</source>
        <translation>基线要求：%1 GB</translation>
    </message>
    <message>
        <source>Data disk %1 GB / %2 GB</source>
        <translation>数据盘 %1 GB/%2 GB</translation>
    </message>
    <message>
        <source>System disk %1 GB / %2 GB</source>
        <translation>系统盘 %1 GB/%2 GB</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>社区版</translation>
    </message>
    <message>
        <source>Professional</source>
        <translation>专业版</translation>
    </message>
</context>
<context>
    <name>DBusWorker</name>
    <message>
        <source>Backup failed</source>
        <translation>备份失败</translation>
    </message>
    <message>
        <source>Upgrade failed</source>
        <translation>升级失败</translation>
    </message>
    <message>
        <source>Restoration failed</source>
        <translation>还原失败</translation>
    </message>
</context>
<context>
    <name>FileDownloader</name>
    <message>
        <source>URL &quot;%1&quot; is illegal</source>
        <translation>“%1”为非法地址</translation>
    </message>
</context>
<context>
    <name>ImageDownloadWidget</name>
    <message>
        <source>Downloading the V23 image file</source>
        <translation>正在下载V23镜像</translation>
    </message>
    <message>
        <source>You can continue using the computer without being affected</source>
        <translation>你可以继续使用电脑，丝毫不受影响</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Time remaining: %1 / File size: %2 GB</source>
        <translation>预计剩余时间：%1  /  镜像大小：%2 GB</translation>
    </message>
</context>
<context>
    <name>ImagePreparationWidget</name>
    <message>
        <source>Download failed</source>
        <translation>下载失败</translation>
    </message>
    <message>
        <source>Do you want to exit the downloading?</source>
        <translation>确定退出镜像下载吗？</translation>
    </message>
    <message>
        <source>Do you want to exit the image file checking?</source>
        <translation>确定退出镜像检查吗？</translation>
    </message>
    <message>
        <source>Start Upgrade</source>
        <translation>去升级</translation>
    </message>
    <message>
        <source>Reselect</source>
        <translation>重新获取</translation>
    </message>
    <message>
        <source>Errors:</source>
        <translation>错误信息：</translation>
    </message>
    <message>
        <source>Error code:</source>
        <translation>错误码：</translation>
    </message>
    <message>
        <source>Failed to connect to the server. Please check your network connection or select a local V23 image file.</source>
        <translation>无法连接服务器！请检查网络连接或者选择本地V23镜像文件</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <source>Your computer is not plugged in, please plug in a power cord first and then upgrade.</source>
        <translation>您未连接电源，请连接电源再升级</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Do you want to exit software evaluation?</source>
        <translation>确定退出软件评估吗？</translation>
    </message>
    <message>
        <source>Software evaluation failed</source>
        <translation>软件评估失败</translation>
    </message>
</context>
<context>
    <name>InitialWidget</name>
    <message>
        <source>Deepin Upgrade</source>
        <translation type="vanished">Deepin系统升级</translation>
    </message>
    <message>
        <source>Current version: V%1</source>
        <translation>当前版本：V%1</translation>
    </message>
    <message>
        <source>Take a few simple steps to upgrade your system to</source>
        <translation>只需一些简单的操作即可帮助您的计算机升级至</translation>
    </message>
    <message>
        <source>Deepin 23</source>
        <translation type="vanished">Deepin 23</translation>
    </message>
    <message>
        <source>I have read and agreed to the </source>
        <translation type="vanished">我已阅读并同意</translation>
    </message>
    <message>
        <source>《Deepin系统升级工具》</source>
        <translation type="vanished">《Deepin系统升级工具》</translation>
    </message>
    <message>
        <source>Pre-Check</source>
        <translation>升级检查</translation>
    </message>
    <message>
        <source>Deepin Upgrade Tool</source>
        <translation type="vanished">Deepin系统升级工具</translation>
    </message>
    <message>
        <source>Disagree</source>
        <translation>不同意</translation>
    </message>
    <message>
        <source>Agree</source>
        <translation>同意</translation>
    </message>
    <message>
        <source>End User License Agreement for Deepin Upgrade Tool</source>
        <translatorcomment>标题</translatorcomment>
        <translation>Deepin系统升级工具软件最终用户许可协议</translation>
    </message>
    <message>
        <source>:/text/end_user_license_en.txt</source>
        <translation>:/text/end_user_license_zh_CN.txt</translation>
    </message>
    <message>
        <source>Privacy Protection Guide for Deepin Upgrade Tool</source>
        <translatorcomment>标题</translatorcomment>
        <translation>Deepin系统升级工具软件隐私保护指引</translation>
    </message>
    <message>
        <source>:/text/privacy_protection_guide_en.txt</source>
        <translation>:/text/privacy_protection_guide_zh_CN.txt</translation>
    </message>
    <message>
        <source>End User License Agreement for Deepin Upgrade Tool.</source>
        <translatorcomment>用户协议标签名</translatorcomment>
        <translation type="vanished">《Deepin系统升级工具软件最终用户许可协议》。</translation>
    </message>
    <message>
        <source>Privacy Protection Guide for Deepin Upgrade Tool.</source>
        <translatorcomment>隐私标签名</translatorcomment>
        <translation type="vanished">《Deepin系统升级工具软件隐私保护指引》。</translation>
    </message>
    <message>
        <source>&quot;End User License Agreement for Deepin Upgrade Tool&quot;</source>
        <translatorcomment>勾选框文字标题。</translatorcomment>
        <translation>《最终用户许可协议》</translation>
    </message>
    <message>
        <source>&quot;Privacy Protection Guide&quot;</source>
        <translation>《隐私保护指引》</translation>
    </message>
    <message>
        <source>I have read and agreed to the &lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt; and &lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;.</source>
        <translation>我已阅读并同意&lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt;和&lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>System Upgrade Tool</source>
        <translation>系统升级工具</translation>
    </message>
    <message>
        <source>deepin 23</source>
        <translation>deepin 23</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Do you want to exit the Deepin Upgrade Tool?</source>
        <translation>确定退出Deepin系统升级工具吗？</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Upgrade failed</source>
        <translation>升级失败</translation>
    </message>
</context>
<context>
    <name>MigrateFinishedWidget</name>
    <message>
        <source>App migration successful</source>
        <translation>应用迁移成功</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>MigrateProgressWidget</name>
    <message>
        <source>Migrating apps</source>
        <translation>应用迁移中</translation>
    </message>
    <message>
        <source>Migrating apps, please wait patiently</source>
        <translation>应用迁移中，请耐心等候</translation>
    </message>
    <message>
        <source>Reconnect</source>
        <translation>重新连接</translation>
    </message>
    <message>
        <source>Network error. App migration has been interrupted.</source>
        <translation>网络异常，应用迁移已中断</translation>
    </message>
    <message>
        <source>Network connection failed. Please check your network.</source>
        <translation>连接不到网络，请检查您的网络</translation>
    </message>
</context>
<context>
    <name>MigrateWidget</name>
    <message>
        <source>App migration failed</source>
        <translation>应用迁移失败</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>反馈</translation>
    </message>
</context>
<context>
    <name>ProgressWidget</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Time remaining: %1</source>
        <translation>预计剩余时间：%1</translation>
    </message>
</context>
<context>
    <name>RestorationWidget</name>
    <message>
        <source>Restoring…</source>
        <translation>系统还原中...</translation>
    </message>
    <message>
        <source>Upgrade failed. Your system is being restored to the previous version.</source>
        <translation>系统升级失败，正在为您还原系统，请稍侯</translation>
    </message>
</context>
<context>
    <name>RetrieveImageMethodWidget</name>
    <message>
        <source>Get Image Files</source>
        <translation>请选择镜像获取方式</translation>
    </message>
    <message>
        <source>Download from Internet</source>
        <translation>联网下载</translation>
    </message>
    <message>
        <source>Import local image files</source>
        <translation>本地导入镜像文件</translation>
    </message>
    <message>
        <source>Format: ISO</source>
        <translation>只支持扩展名：ISO</translation>
    </message>
    <message>
        <source>Drag files here</source>
        <translation>拖拽文件至此处</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>选择文件</translation>
    </message>
</context>
<context>
    <name>SoftwareCheckProgressWidget</name>
    <message>
        <source>Pre-Check</source>
        <translation type="obsolete">升级检查</translation>
    </message>
    <message>
        <source>Check your computer to see if it meets the upgrade conditions</source>
        <translation type="obsolete">升级前，需检查是否满足升级的基本条件</translation>
    </message>
    <message>
        <source>Software Evaluation</source>
        <translation>软件评估</translation>
    </message>
    <message>
        <source>Evaluate the compatibility of installed apps in the new system</source>
        <translation>评估已安装软件在新系统中的兼容性</translation>
    </message>
</context>
<context>
    <name>SoftwareEvaluationOfflineWidget</name>
    <message>
        <source>Software Evaluation</source>
        <translation>软件评估</translation>
    </message>
    <message>
        <source>Your current usage scenario is in a state of no network. We cannot evaluate the software you are using. After the upgrade is complete, the software you are currently installing needs to be reinstalled. If you want to view the details of the applications that can be installed for the upgrade, please upgrade online</source>
        <translation>您当前的使用场景处于无网络状态，我们无法对你正在使用的软件进行评估，升级完成后您当前所安装的软件需要重新进行安装，如需查看升级可安装应用详情请联网升级</translation>
    </message>
</context>
<context>
    <name>SoftwareEvaluationWidget</name>
    <message>
        <source>Compatible</source>
        <translation type="vanished">兼容</translation>
    </message>
    <message>
        <source>Incompatible</source>
        <translation type="vanished">不兼容</translation>
    </message>
    <message>
        <source>Evaluation Result</source>
        <translation>软件评估结果</translation>
    </message>
    <message>
        <source>The upgrade may take a long time. Please plug in to avoid interruption.</source>
        <translation>升级时间可能较长，请插上电源以免升级中断</translation>
    </message>
    <message>
        <source>Compatible Apps</source>
        <translation>兼容应用</translation>
    </message>
    <message>
        <source>Incompatible Apps</source>
        <translation>不兼容应用</translation>
    </message>
    <message>
        <source>V23 version supports applications</source>
        <translation type="vanished">V23版本支持应用</translation>
    </message>
    <message>
        <source>The V23 version does not support the application</source>
        <translation type="vanished">V23版本不支持应用</translation>
    </message>
    <message>
        <source>The system upgrade will ensure the integrity of user data, and we will not delete user data</source>
        <translation>系统升级会保证用户数据的完整性，我们不会对用户数据进行删减</translation>
    </message>
    <message>
        <source>By default, the cross-version upgrade does not migrate the installed applications. After the upgrade is completed, the system will automatically install the selected applications in the list. Please select the software that needs to be installed after the upgrade is complete</source>
        <translation type="vanished">跨版本升级默认不对已安装应用进行迁移，完成升级后系统会对列表勾选应用进行自动化安装，请选择升级完成后需要安装的应用</translation>
    </message>
    <message>
        <source>The cross-version upgrade does not migrate the application. After the upgrade is completed, it supports automatic installation of the selected compatible application</source>
        <translation>跨版本升级不对应用进行迁移，升级完成后支持对已勾选兼容应用自动化安装</translation>
    </message>
</context>
<context>
    <name>StorageResultWidget</name>
    <message>
        <source>Free up</source>
        <translation>清理</translation>
    </message>
    <message>
        <source>Your system cannot be upgraded to V23</source>
        <translation>当前空间不支持升级V23！</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Clean system disk</source>
        <translation>清理系统盘</translation>
    </message>
    <message>
        <source>%1 GB free space required</source>
        <translation>系统盘还需要%1 GB空间</translation>
    </message>
    <message>
        <source>Free Up</source>
        <translation>去清理</translation>
    </message>
    <message>
        <source>Clean data disk</source>
        <translation>清理数据盘</translation>
    </message>
    <message>
        <source>System backup only, no app backup</source>
        <translation type="vanished">仅备份系统，不备份应用</translation>
    </message>
    <message>
        <source>Less disk space is required if enabled, but some apps may not work properly after restoring the system from version 23.</source>
        <translation type="vanished">开启此功能将降低备份空间要求，但从V23还原至当前系统时，部分应用可能不可用</translation>
    </message>
</context>
<context>
    <name>SystemUpgradeWidget</name>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>重新备份</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>反馈</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>备份失败</translation>
    </message>
    <message>
        <source>Restoration failed</source>
        <translation>还原失败</translation>
    </message>
    <message>
        <source>After clicking restart, the system will be upgraded, please save the current running application data before confirming</source>
        <translation>点击重启后系统将进行升级，确认前请对当前运行应用数据进行保存</translation>
    </message>
    <message>
        <source>Restart now</source>
        <translation>立即重启</translation>
    </message>
</context>
<context>
    <name>UpgradeCheckProgressWidget</name>
    <message>
        <source>Pre-Check</source>
        <translation>升级检查</translation>
    </message>
    <message>
        <source>Check your computer to see if it meets the upgrade conditions</source>
        <translation>升级前，需检查是否满足升级的基本条件</translation>
    </message>
</context>
<context>
    <name>UpgradeCheckResultWidget</name>
    <message>
        <source>Check Conditions</source>
        <translation type="vanished">条件检查</translation>
    </message>
    <message>
        <source>Software Changes</source>
        <translation type="vanished">软件评估</translation>
    </message>
    <message>
        <source>Passed</source>
        <translation>检查通过</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>检查未通过</translation>
    </message>
</context>
<context>
    <name>UpgradeCheckWidget</name>
    <message>
        <source>Do you want to exit the pre-upgrade checking?</source>
        <translation>确定退出升级检查吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>重新检查</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
</context>
<context>
    <name>UpgradeWidget</name>
    <message>
        <source>Upgrading…</source>
        <translation>系统升级中...</translation>
    </message>
    <message>
        <source>Preparing for system upgrade, please wait patiently</source>
        <translation>系统升级准备中,请耐心等候</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Deepin Upgrade Tool</source>
        <translation>Deepin系统升级工具</translation>
    </message>
    <message>
        <source>Deepin Upgrade Tool helps you upgrade the system to version 23.</source>
        <translation>Deepin系统升级工具是一款将系统升级为V23的小工具。</translation>
    </message>
    <message>
        <source>Upgrade successful</source>
        <translation>系统升级成功</translation>
    </message>
    <message>
        <source>Successfully upgraded to version %1</source>
        <translation>已成功升级至V%1系统</translation>
    </message>
    <message>
        <source>Error code: %1</source>
        <translation>错误码：%1</translation>
    </message>
</context>
</TS>
